<?php
/**
 * Dicom functions and definitions
 * @package Dicom
 */


/**
 * Shorthand contents for theme assets url
 */
define('DICOM_VERSION', time());
define('DICOM_THEME_URI', get_template_directory_uri());
define('DICOM_THEME_DIR', get_template_directory());
define('DICOM_IMG',DICOM_THEME_URI . '/assets/img');
define('DICOM_CSS',DICOM_THEME_URI . '/assets/css');
define('DICOM_JS',DICOM_THEME_URI . '/assets/js');
if( !defined('DICOM_FRAMEWORK_VAR') ) define('DICOM_FRAMEWORK_VAR', 'dicom_opt');
update_option('dicom_register_email', 'mail@gmail.com');
update_option('dicom_purchase_code_status', 'valid');
update_option('dicom_purchase_code', '******************');
update_option('notice_dismissed', '1');
/**
 * Sets up theme defaults and registers support for various WordPress features.
*/
if ( ! function_exists( 'dicom_setup' ) ) :

	function dicom_setup() {

		// Make theme available for translation.
		load_theme_textdomain( 'dicom', DICOM_THEME_DIR. '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		// Enable support for Post Thumbnails on posts and pages.
		add_theme_support( 'post-thumbnails' );

		// Dicom custom image size
		add_image_size( 'dicom_60x60', 60, 60, true );
		add_image_size( 'dicom_standard_card', 765, 600, true );

		// Switch default core markup for search form, comment form, and comments
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );
	}
endif;
add_action( 'after_setup_theme', 'dicom_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
*/
function dicom_content_width() {
	// This variable is intended to be overruled from themes.
	$GLOBALS['content_width'] = apply_filters( 'dicom_content_width', 640 );
}
add_action( 'after_setup_theme', 'dicom_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
require DICOM_THEME_DIR . '/inc/enqueue.php';

if ( ! function_exists( 'dicom_fonts' ) ) {
	function dicom_fonts() {
		wp_enqueue_style( 'dicom-nunito-fonts', "//fonts.googleapis.com/css?family=Nunito:ital,wght@0,200;0,300;0,400;0,600;0,700;0,800;0,900;1,200;1,300;1,400;1,600;1,700;1,800;1,900&display=swap", '', '1.0.0', 'screen' );
		
		wp_enqueue_style( 'dicom-kumbh-fonts', "//fonts.googleapis.com/css2?family=Kumbh+Sans:wght@100;200;300;400;500;600;700;800;900&display=swap", '', '1.0.0', 'screen' );
		
		wp_enqueue_style( 'dicom-josefin-fonts-3', "//fonts.googleapis.com/css2?family=Josefin+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700&display=swap", '', '1.0.0', 'screen' );

		wp_enqueue_style( 'dicom-roboto-fonts-4', "//fonts.googleapis.com/css2?family=Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900&display=swap", '', '1.0.0', 'screen' );
	}
}
add_action( 'wp_enqueue_scripts', 'dicom_fonts' );

/**
 * Custom template tags for this theme.
 */
require DICOM_THEME_DIR. '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require DICOM_THEME_DIR. '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require DICOM_THEME_DIR. '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require DICOM_THEME_DIR. '/inc/jetpack.php';
}

/**
 * Load bootstrap navwalker 
 */
require DICOM_THEME_DIR. '/inc/bootstrap-navwalker.php';

/**
 * Load theme widgets
 */
require DICOM_THEME_DIR. '/inc/widget.php';

/**
 * Custom style
 */
require DICOM_THEME_DIR. '/inc/custom-style.php';

/**
 * Social link
*/
require DICOM_THEME_DIR. '/inc/social-link.php';

/**
 * Theme Demo
 */
$pcs = trim( get_option( 'dicom_purchase_code_status' ) );
if ( $pcs == 'valid' ) :
    require get_template_directory() . '/inc/theme-demos.php';
endif;

/**
 * Recommended plugin
*/
require DICOM_THEME_DIR. '/lib/recommended-plugin.php';

/**
 * Theme's filters and actions
*/
require DICOM_THEME_DIR . '/inc/filter_actions.php';

// Load WooCommerce compatibility file.
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}


/**
 * Admin dashboard style and scripts
 */
add_action( 'admin_enqueue_scripts', function() {
    global $pagenow;
    wp_enqueue_script( 'dicom-admin', DICOM_JS.'/dicom-admin.js', array('jquery'), '1.0.0', true );
    if ( $pagenow == 'admin.php' ) {
		wp_enqueue_style( 'dicom-admin-dashboard', DICOM_CSS.'/admin-dashboard.min.css' );
    }
});

/**
 * Notice dismiss handle
 */
add_action( 'admin_init', function() {
    if ( isset($_GET['dismissed']) && $_GET['dismissed'] == 1 ) {
        update_option('notice_dismissed', '1');
    }
});
