<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to dicom/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */

defined( 'ABSPATH' ) || exit;

get_header( 'shop' );

global $dicom_opt;

/**
 * Hook: woocommerce_before_main_content.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 * @hooked WC_Structured_Data::generate_website_data() - 30
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

do_action( 'woocommerce_before_main_content' );

if ( isset( $dicom_opt['blog_title'] ) ): 
    $hide_banner        = $dicom_opt['enable_shop_pages_banner'];
    $hide_breadcrumb    = $dicom_opt['hide_woo_breadcrumb'];
else:
    $hide_banner        = false;
    $hide_breadcrumb    = false;
endif;

if( $hide_banner == true ):
    $page_spac   = '';
else:
    $page_spac   = 'mt-80';
endif;
$enable_lines = !empty($dicom_opt['enable_lines']) ? $dicom_opt['enable_lines'] : '';

$dicom_product_layout = !empty($dicom_opt['dicom_product_layout']) ? $dicom_opt['dicom_product_layout'] : 'container';
if ( !empty($_GET['dicom_product_layout']) ) {
    $dicom_product_layout = $_GET['dicom_product_layout'];
}
if( isset($dicom_opt['page_title_tag']) ):
    $tag = $dicom_opt['page_title_tag'];
else:
    $tag = 'h2';
endif;
?> 

<?php if( $hide_banner == true ) { ?>
    <div class="page-title-area">
        <div class="container">
            <div class="page-title-content">
                <?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
                    <<?php echo esc_attr( $tag ); ?>><?php woocommerce_page_title(); ?></<?php echo esc_attr( $tag ); ?>>
                    <?php if( $hide_breadcrumb != true ): 
                        if ( function_exists('yoast_breadcrumb') ):
                            yoast_breadcrumb( '<p class="dicom-seo-breadcrumbs" id="breadcrumbs">','</p>' );
                        else: ?>
                            <ul>
                                <li><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php esc_html_e( 'Home', 'dicom' ); ?></a></li>
                                <li><?php woocommerce_page_title(); ?></li>
                            </ul><?php
                        endif; ?>
                    <?php endif; ?>
                <?php endif; ?>
            </div>
        </div>
        <?php dicom_page_shape_images(); ?>
        
        <?php if( $enable_lines == true ) : ?>
            <div class="lines">
                <div class="line"></div>
                <div class="line"></div>
                <div class="line"></div>
            </div>
        <?php endif; ?>
    </div>
<?php } ?>
  
<div class="products-area ptb-100 <?php echo esc_attr( $page_spac ); ?>">
    <div class="<?php echo esc_attr( $dicom_product_layout ); ?>">
        <div class="row">
            <?php if ( is_active_sidebar( 'shop' ) ): ?>
                 <?php if ( isset( $_GET['shop-sidebar'] ) ): ?>
                    <?php  $dicom_shop_cat_sidebar = $_GET['shop-sidebar']; ?>
                    <?php if ( $dicom_shop_cat_sidebar == 'none' ): ?>
                        <div class="col-lg-12 col-md-12">
                    <?php elseif ( $dicom_shop_cat_sidebar == 'left' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $dicom_shop_cat_sidebar == 'right' ): ?>
                        <div class="col-lg-8 col-md-12">
                    <?php endif; ?>
                <?php else: ?>
                    <?php if( $dicom_opt['dicom_product_sidebar'] == 'dicom_product_left_sidebar' ): ?>
                        <?php do_action( 'woocommerce_sidebar' ); ?>
                        <div class="col-lg-8 col-md-12">
                    <?php elseif ( $dicom_opt['dicom_product_sidebar'] == 'dicom_product_right_sidebar' ): ?>
                        <div class="col-lg-8 col-md-12">
                    <?php else: ?>
                        <div class="col-lg-12 col-md-12">
                    <?php endif; ?>
                <?php endif; ?>
            <?php else: ?>
                <div class="col-lg-12 col-md-12">
            <?php endif; ?>
                <?php
                if ( woocommerce_product_loop() ) {

                    /**
                     * Hook: woocommerce_before_shop_loop.
                     *
                     * @hooked woocommerce_output_all_notices - 10
                     * @hooked woocommerce_result_count - 20
                     * @hooked woocommerce_catalog_ordering - 30
                     */

                    ?>
                    <div class="woocommerce-topbar">
                        <?php do_action( 'woocommerce_before_shop_loop' ); ?>
                    </div>
                    <?Php

                    woocommerce_product_loop_start();

                    if ( wc_get_loop_prop( 'total' ) ) {
                        while ( have_posts() ) {
                            the_post();

                            /**
                             * Hook: woocommerce_shop_loop.
                             *
                             * @hooked WC_Structured_Data::generate_product_data() - 10
                             */
                            do_action( 'woocommerce_shop_loop' );

                            wc_get_template_part( 'content', 'product' );
                        }
                    }

                    woocommerce_product_loop_end();

                    /**
                     * Hook: woocommerce_after_shop_loop.
                     *
                     * @hooked woocommerce_pagination - 10
                     */
                    do_action( 'woocommerce_after_shop_loop' );
                } else {
                    /**
                     * Hook: woocommerce_no_products_found.
                     *
                     * @hooked wc_no_products_found - 10
                     */
                    do_action( 'woocommerce_no_products_found' );
                }
                ?>
            </div> <!-- end clo-8 -->
            
            <?php 
            if ( isset( $_GET['shop-sidebar'] ) ):
                if ( $dicom_shop_cat_sidebar == 'right' ) :
                    do_action( 'woocommerce_sidebar' );
                endif; 
            else:
                if ( $dicom_opt['dicom_product_sidebar'] == 'dicom_product_right_sidebar' ):
                    do_action( 'woocommerce_sidebar' );
                endif; 
            endif; 
            ?>
        </div>
            <?php
            /**
             * Hook: woocommerce_after_main_content.
             *
             * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
             */
            do_action( 'woocommerce_after_main_content' );

            /**
             * Hook: woocommerce_sidebar.
             *
             * @hooked woocommerce_get_sidebar - 10
             */

            get_footer( 'shop' );

            ?>
        </div>
    </div>
</div>