<?php
/**
 * The Template for displaying all single products
 *
 * This template can be overridden by copying it to dicom/woocommerce/single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @package 	WooCommerce/Templates
 * @version     1.6.4
 */
global $dicom_opt;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $dicom_opt;

get_header( 'shop' );

if ( isset( $dicom_opt['blog_title'] ) ): 
    $hide_banner        = $dicom_opt['enable_shop_pages_banner'];
    $hide_breadcrumb    = $dicom_opt['hide_woo_breadcrumb'];
else:
    $hide_banner        = false;
    $hide_breadcrumb    = false;
endif;

if( $hide_banner == true ):
    $page_spac   = '';
else:
    $page_spac   = 'mt-80';
endif;
$enable_lines = !empty($dicom_opt['enable_lines']) ? $dicom_opt['enable_lines'] : '';

remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

$dicom_product_layout = !empty($dicom_opt['dicom_single_product_layout']) ? $dicom_opt['dicom_single_product_layout'] : 'container';
if ( !empty($_GET['dicom_single_product_layout']) ) {
    $dicom_product_layout = $_GET['dicom_single_product_layout'];
}

if( isset($dicom_opt['page_title_tag']) ):
    $tag = $dicom_opt['page_title_tag'];
else:
    $tag = 'h2';
endif;
?>

    <?php if( $hide_banner == true ) { ?>
        <div class="page-title-area">
            <div class="container">
                <div class="page-title-content">
                    <<?php echo esc_attr( $tag ); ?>><?php the_title(); ?></<?php echo esc_attr( $tag ); ?>>
                    <?php if ( $hide_breadcrumb != true ) : 

                        if ( function_exists('yoast_breadcrumb') ):
                            yoast_breadcrumb( '<p class="dicom-seo-breadcrumbs" id="breadcrumbs">','</p>' );
                        else: ?>
                            <ul>
                                <li><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php esc_html_e( 'Home', 'dicom' ); ?></a></li>
                                <li><?php the_title(); ?></li>
                            </ul><?php
                        endif; ?>
                    <?php endif; ?>
                </div>
            </div>
            <?php dicom_page_shape_images(); ?>
            
            <?php if( $enable_lines == true ) : ?>
                <div class="lines">
                    <div class="line"></div>
                    <div class="line"></div>
                    <div class="line"></div>
                </div>
            <?php endif; ?>
        </div>
    <?php } ?>

    <div class="products-area products_details ptb-100 <?php echo esc_attr( $page_spac ); ?>">
        <div class="<?php echo esc_attr( $dicom_product_layout ); ?>">
            <div class="row">                
                <?php if ( is_active_sidebar( 'shop' ) ): ?>
                    <?php if ( isset( $_GET['shop-sidebar'] ) ): ?>
                        <?php  $dicom_shop_cat_sidebar = $_GET['shop-sidebar']; ?>
                        <?php if ( $dicom_shop_cat_sidebar == 'none' ): ?>
                            <div class="col-lg-12 col-md-12">
                        <?php elseif ( $dicom_shop_cat_sidebar == 'left' ): ?>
                            <?php do_action( 'woocommerce_sidebar' ); ?>
                            <div class="col-lg-8 col-md-12">
                        <?php elseif ( $dicom_shop_cat_sidebar == 'right' ): ?>
                            <div class="col-lg-8 col-md-12">
                        <?php endif; ?>
                    <?php else: ?>
                        <?php if( $dicom_opt['dicom_product_sidebar'] == 'dicom_product_left_sidebar' ): ?>
                            <?php do_action( 'woocommerce_sidebar' ); ?>
                            <div class="col-lg-8 col-md-12">
                        <?php elseif ( $dicom_opt['dicom_product_sidebar'] == 'dicom_product_right_sidebar' ): ?>
                            <div class="col-lg-8 col-md-12">
                        <?php else: ?>
                            <div class="col-lg-12 col-md-12">
                        <?php endif; ?>
                    <?php endif; ?>
                <?php else: ?>
                    <div class="col-lg-12 col-md-12">
                <?php endif; ?>

                    <?php
                    /**
                     * woocommerce_before_main_content hook.
                     *
                     * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
                     * @hooked woocommerce_breadcrumb - 20
                     */

                    do_action( 'woocommerce_before_main_content' );
                    ?>

                        <?php while ( have_posts() ) : the_post(); ?>

                            <?php wc_get_template_part( 'content', 'single-product' ); ?>

                        <?php endwhile; // end of the loop. ?>

                    <?php
                        /**
                         * woocommerce_after_main_content hook.
                         *
                         * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
                         */
                        do_action( 'woocommerce_after_main_content' );
                    ?>
                </div>
                <?php 
                if ( isset( $_GET['shop-sidebar'] ) ):
                    if ( $dicom_shop_cat_sidebar == 'right' ) :
                        do_action( 'woocommerce_sidebar' );
                    endif; 
                else:
                    if ( $dicom_opt['dicom_product_sidebar'] == 'dicom_product_right_sidebar' ):
                        do_action( 'woocommerce_sidebar' );
                    endif; 
                endif; 
                ?>
            </div>
        </div>
    </div>
    <?php get_footer( 'shop' );

    /* Omit closing PHP tag at the end of PHP files to avoid "headers already sent" issues. */
    ?>